@@ -42,10 +42,19 @@ class NameResolver(CodeGenerator):
                     raise 
                     #raise Exception("Undefined reference %s" % field.type)
 
-            if isinstance(field.type, nodes.EnumNode):
-                if hasattr(field, 'default'):
-                    # XXX: if dotted, resolve the name
-                    field.default_node = field.type.get(field.default)
+            if hasattr(field, 'default'):
+                # enum nodes defaults are constrainted to the enum
+                if isinstance(field.type, nodes.EnumNode):
+                    # if the name is a member of the enum, use that
+                    if field.type.has(field.default):
+                        field.default_node = field.type.get(field.default)
+                    else:
+                        field.default_node = frame.resolve_name(field.default)
+                elif not field.default.isdigit():
+                    # resolve the name (if its a name)
+                    field.default_node = frame.resolve_name(field.default)
+                else:
+                    field.default = field.default.strip("'\"")
 
             
             
